@@ -618,9 +618,9 @@ if (!is.na(mean1)) {
 
   result.table <- NTplotTable(distribution.name= distribution.name,
                                    type=              type,
-                                   mean0=             top.axis.vector["mean0"],
-                                   mean1=             top.axis.vector["mean1"],
-                                   xbar=              top.axis.vector["xbar"],
+                                   mean0=             mean0, ## top.axis.vector["mean0"],
+                                   mean1=             mean1, ## top.axis.vector["mean1"],
+                                   xbar=              xbar,  ## top.axis.vector["xbar"],
                                    ## sd=                sd,
                                    df=                df,
                                    n=                 n,
@@ -629,20 +629,20 @@ if (!is.na(mean1)) {
                                    stderr=            stderr,
                                    sigma.p1=          sigma.p1,
                                    zc.right=          zc.right,
-                                   xbarc.right=       top.axis.vector["xbarc.right"],
+                                   xbarc.right=       xbarc.right, ## top.axis.vector["xbarc.right"],
                                    zc.left=           zc.left,
-                                   xbarc.left=        top.axis.vector["xbarc.left"],
+                                   xbarc.left=        xbarc.left,  ## top.axis.vector["xbarc.left"],
                                    sided=             sided,
                                    xbar.left=         xbar.left,
                                    xbar.right=        xbar.right,
-                                   xbar.otherside=    top.axis.vector["xbar.otherside"],
+                                   xbar.otherside=    xbar.otherside, ## top.axis.vector["xbar.otherside"],
                                    pvalue.left=       pvalue.left,
                                    pvalue.right=      pvalue.right,
                                    pvalue=            pvalue,
                                    power.left=        power.left,
                                    power.right=       power.right,
                                    power.total=       power.total,
-                                   conf.left=         alpha.left, ## ifelse(sided != "right", 1 - alpha.right, alpha.right),
+                                   conf.left=         alpha.left,  ## ifelse(sided != "right", 1 - alpha.right, alpha.right),
                                    conf.right=        alpha.right, ## ifelse(sided != "left", 1 - alpha.left, alpha.left),
                                    conf=              1 - (alpha.left + alpha.right),
                                    mean0.alist=       mean0.alist,
@@ -759,7 +759,7 @@ if (!is.na(mean1)) {
 
 print.NormalAndTplot <- function(x, tablesOnPlot=TRUE, plot=TRUE,
                                  scales=FALSE, prob=FALSE, call=FALSE,
-                                 ..., cex.table=.7, digits=getOption("digits"),
+                                 ..., cex.table=.7, digits=attr(x, "call.list")$digits, ## getOption("digits"),
                                  position.2=.17) {
 
   if (scales) {
